"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const apollo_server_core_1 = require("apollo-server-core");
const GraphiQL = __importStar(require("apollo-server-module-graphiql"));
function graphqlKoa(options) {
    if (!options) {
        throw new Error('Apollo Server requires options.');
    }
    if (arguments.length > 1) {
        throw new Error(`Apollo Server expects exactly one argument, got ${arguments.length}`);
    }
    const graphqlHandler = (ctx) => {
        return apollo_server_core_1.runHttpQuery([ctx], {
            method: ctx.request.method,
            options: options,
            query: ctx.request.method === 'POST' ? ctx.request.body : ctx.request.query,
            request: apollo_server_core_1.convertNodeHttpToRequest(ctx.req),
        }).then(gqlResponse => {
            ctx.set('Content-Type', 'application/json');
            ctx.body = gqlResponse;
        }, (error) => {
            if ('HttpQueryError' !== error.name) {
                throw error;
            }
            if (error.headers) {
                Object.keys(error.headers).forEach(header => {
                    ctx.set(header, error.headers[header]);
                });
            }
            ctx.status = error.statusCode;
            ctx.body = error.message;
        });
    };
    return graphqlHandler;
}
exports.graphqlKoa = graphqlKoa;
function graphiqlKoa(options) {
    const graphiqlHandler = (ctx) => {
        const query = ctx.request.query;
        return GraphiQL.resolveGraphiQLString(query, options, ctx).then(graphiqlString => {
            ctx.set('Content-Type', 'text/html');
            ctx.body = graphiqlString;
        }, error => {
            ctx.status = 500;
            ctx.body = error.message;
        });
    };
    return graphiqlHandler;
}
exports.graphiqlKoa = graphiqlKoa;
//# sourceMappingURL=koaApollo.js.map